@@ -20,13 +20,14 @@ import logging
 
 from doorstop.common import HelpFormatter, WarningFormatter, DoorstopError
 from doorstop.core import vcs
-from doorstop.core import tree
+from doorstop.core import builder
 from doorstop import settings
 
 
 def main(args=None):
     """Process command-line arguments and run the program."""
     from doorstop import GUI, VERSION
+
     # Main parser
     debug = argparse.ArgumentParser(add_help=False)
     debug.add_argument('-V', '--version', action='version', version=VERSION)
@@ -78,9 +79,9 @@ def _configure_logging(verbosity=0):
 def _run(args, cwd, error):
     """Start the GUI.
 
-    @param args: Namespace of CLI arguments (from this module or the CLI)
-    @param cwd: current working directory
-    @param error: function to call for CLI errors
+    :param args: Namespace of CLI arguments (from this module or the CLI)
+    :param cwd: current working directory
+    :param error: function to call for CLI errors
 
     """
     from doorstop import __project__, __version__
@@ -414,7 +415,7 @@ class Application(ttk.Frame):  # pragma: no cover (manual test), pylint: disable
     def display_tree(self, *_):
         """Display the currently selected tree."""
         # Set the current tree
-        self.tree = tree.build(root=self.stringvar_project.get())
+        self.tree = builder.build(root=self.stringvar_project.get())
         logging.info("displaying tree...")
 
         # Display the documents in the tree
